Name:           linbox
Version:        1.3.2
Release:        24%{?dist}
Summary:        C++ Library for High-Performance Exact Linear Algebra
Group:          Development/Libraries
License:        LGPLv2+
URL:            http://www.linalg.org/
Source0:        http://www.linalg.org/%{name}-%{version}.tar.gz
# Upstream: 2 Nov 2011.  Fix double frees that crash all tests.
Patch0:         %{name}-destructor.patch
# Upstream: 3 Jan 2013.  Adapt to changes in C++ scope visibility in GCC 4.7.
Patch1:         %{name}-gcc47.patch
# Upstream: 3 Jan 2013.  Correct missing semicolon.
Patch2:         %{name}-int64.patch
# Upstream: 3 Jan 2013.  Force linkage to mpfr and iml to avoid unresolved
# symbols.
Patch3:         %{name}-underlink.patch
# Upstream: 3 Jan 2013.  Fix driver compilation, which has bitrotted somewhat.
Patch4:         %{name}-driver.patch
# Upstream: 3 Jan 2013.  Fix detection of LAPACK support in FFLAS-FFPACK.
Patch5:         %{name}-lapack.patch
# Upstream: 3 Jan 2013.  Adapt to FPLLL 4.x.
Patch6:         %{name}-fplll.patch
# Upstream: 3 Jan 2013.  Fix build when size_t is unsigned long (eg. on s390).
Patch7:         %{name}-size_t.patch

BuildRequires:  atlas-devel
BuildRequires:  fflas-ffpack-devel
BuildRequires:  givaro-devel
BuildRequires:  iml-devel
BuildRequires:  libfplll-devel
BuildRequires:  m4ri-devel
BuildRequires:  m4rie-devel
BuildRequires:  mpfr-devel
BuildRequires:  ntl-devel
BuildRequires:  saclib-devel

BuildRequires:  doxygen
BuildRequires:  ghostscript
BuildRequires:  gnuplot
BuildRequires:  tex(latex)
BuildRequires:  tex(stmaryrd.sty)

%description
LinBox is a C++ template library for exact, high-performance linear
algebra computation with dense, sparse, and structured matrices over
the integers and over finite fields.


%package        devel
Summary:        Development libraries/headers for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       fflas-ffpack-devel%{?_isa}
Requires:       iml-devel%{?_isa}
Requires:       libfplll-devel%{?_isa}
Requires:       ntl-devel%{?_isa}


%description    devel
Headers and libraries for development with %{name}.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
Provides:       bundled(jquery)
BuildArch:      noarch


%description    doc
Documentation for %{name}.


%prep
%setup -q
%patch0
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7 -p1

# Adapt to the way saclib is packaged in Fedora
sed -e 's,include/saclib,&/saclib,' \
    -e '/saclib\.h/,+1s/__GNU_MP_VERSION < 3/SACMAJVERS < 2/' \
    -i configure

# Adapt to givaro 3.8.0
sed -i 's/^version_max=30800/version_max=30900/' configure


%build
CFLAGS="%{optflags} -I%{_includedir}/saclib"
if [ %{__isa_bits} = "64" ]; then
    CFLAGS="$CFLAGS -D__LINBOX_HAVE_INT64=1"
fi
export CFLAGS
CXXFLAGS=$CFLAGS
export CXXFLAGS
CPPFLAGS="$CPPFLAGS -I%{_includedir}/m4rie"
export CPPFLAGS

%configure --enable-shared --disable-static --enable-drivers --enable-sage \
  --enable-optimization --enable-doc --with-ntl --with-saclib

# Remove hardcoded rpaths; workaround libtool reordering -Wl,--as-needed after
# all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC="\(g..\)"|CC="\1 -Wl,--as-needed"|' \
    -i libtool

# Don't try to optimize the tests; the build takes gargantuan amounts of memory
sed -i 's|-O2||g' tests/Makefile

make # %%{?_smp_mflags}

# Don't want these files in with the HTML files
rm -f doc/linbox-html/{AUTHORS,COPYING,INSTALL}


%install
make install DESTDIR=%{buildroot}
rm -f %{buildroot}%{_libdir}/*.la

# Remove docs that are installed in the wrong place
rm -rf %{buildroot}%{_prefix}/doc


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%check
LD_LIBRARY_PATH=`pwd`/linbox/.libs make %{?_smp_mflags} check


%files
%doc AUTHORS ChangeLog NEWS README TODO
%license COPYING
%{_libdir}/*.so.*


%files doc
%doc doc/linbox-html/*


%files devel
%{_includedir}/%{name}
%{_libdir}/*.so
%{_bindir}/%{name}-config
%{_mandir}/man1/%{name}-config.1*


%changelog
* Sat Sep 19 2015 Jerry James <loganjerry@gmail.com> - 1.3.2-24
- Rebuild for ntl 9.3.0

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-23
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 18 2015 Jerry James <loganjerry@gmail.com> - 1.3.2-22
- Rebuild for ntl 9.1.1

* Sat May  9 2015 Jerry James <loganjerry@gmail.com> - 1.3.2-21
- Rebuild for ntl 9.1.0

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 1.3.2-20
- Rebuilt for GCC 5 C++11 ABI change

* Sat Mar 28 2015 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 1.3.2-19
- Rebuild for new c++ string and list abi

* Mon Feb  2 2015 Jerry James <loganjerry@gmail.com> - 1.3.2-18
- Rebuild for ntl 8.1.2

* Thu Jan 15 2015 Jerry James <loganjerry@gmail.com> - 1.3.2-17
- Rebuild for ntl 8.1.0
- Note bundled jquery in the documentation

* Tue Oct 28 2014 Jerry James <loganjerry@gmail.com> - 1.3.2-16
- Rebuild for givaro 3.8.0, m4ri(e) 20140914, and ntl 6.2.1
- Prepare for future saclib support
- Fix license handling

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Apr  2 2014 Jerry James <loganjerry@gmail.com> - 1.3.2-13
- Rebuild for ntl 6.1.0
- Add missing Requires to -devel
- Fix overlinking

* Mon Sep 23 2013 Jerry James <loganjerry@gmail.com> - 1.3.2-12
- Rebuild for atlas 3.10.1

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon May  6 2013 Jerry James <loganjerry@gmail.com> - 1.3.2-10
- Rebuild for libfplll 4.0.3, m4ri and m4rie 20130416, and ntl 6.0.0

* Fri Feb  8 2013 Jerry James <loganjerry@gmail.com> - 1.3.2-9
- Rebuild for givaro 3.7.2

* Wed Jan  2 2013 Dan Horák <dan[at]danny.cz> - 1.3.2-8
- Only s390 needs the size_t fix

* Tue Jan  1 2013 Dan Horák <dan[at]danny.cz> - 1.3.2-7
- Fix build when size_t is unsigned long (eg. on s390)

* Mon Dec 31 2012 Jerry James <loganjerry@gmail.com> - 1.3.2-6
- Rebuild for m4ri 20121224

* Mon Dec 10 2012 Jerry James <loganjerry@gmail.com> - 1.3.2-5
- Enable FPLLL support
- Adjust BRs for texlive 2012

* Tue Oct  2 2012 Jerry James <loganjerry@gmail.com> - 1.3.2-4
- Rebuild for givaro 3.7.1
- Fix all linkage problems in the same patch
- Fix driver compile

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Jul 3 2012 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 1.3.2-2
- Force linkage to mpfr and iml to avoid unresolved symbols.

* Tue Jul 3 2012 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 1.3.2-1
- Update to latest upstream release.
- Rediff linbox-destructor patch.
- Rediff gcc 4.7 patch as it is partially applied to upstream tarball.
- Correct 64 bit build.
- Add m4rie-devel to build requires and set CPPFLAGS to detect it.
- Disable --enable-driver as it no longer compiles.

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.2-4
- Rebuilt for c++ ABI breakage

* Mon Jan  9 2012 Jerry James <loganjerry@gmail.com> - 1.2.2-3
- Rebuild for GCC 4.7

* Wed Nov  9 2011 Jerry James <loganjerry@gmail.com> - 1.2.2-2
- New -destructor patch that doesn't cause memory leaks

* Tue Nov  1 2011 Jerry James <loganjerry@gmail.com> - 1.2.2-1
- Update to new upstream release
- Reenable the tests

* Wed Oct 26 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.2.1-1.2
- rebuild with new gmp without compat lib

* Wed Oct 12 2011 Peter Schiffer <pschiffe@redhat.com> - 1.2.1-1.1
- rebuild with new gmp

* Mon Aug 29 2011 Jerry James <loganjerry@gmail.com> - 1.2.1-1
- Final 1.2.1 release

* Tue Jul  5 2011 Jerry James <loganjerry@gmail.com> - 1.2.1-0.1.svn3901
- Update to snapshot with fixes for Fedora
- Drop all patches, now upstream
- Remove unnecessary spec file elements (%%defattr, etc.)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.7-0.3.svn3214
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Feb 14 2010 Thomas Spura <tomspur@fedoraproject.org> - 1.1.7-0.2.svn3212
- add ugly sed to configure to look for *.so and not for *.a anymore
  (atlas maintainer removed them)
  (fixes FTBFS #564837)

* Sat Nov 21 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.7-0.1.svn3214
- fetch new version from svn
  (fixes FTBFS bug #539006)
- change summary to *exact* linear algebra as requested by upstream
- change building a bit

* Mon Oct 19 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-6
- installing docs breaks naming guidelines -> install them different

* Sun Oct 18 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-5
- properly install docs and don't mv them around
- add other files to %%doc

* Sun Oct 18 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-4
- %%check
- patch for --cflags and --lflags in config

* Sat Oct 17 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-3
- patches are send upstream
- correct BuildRequires
- INSTALL is not in %%doc

* Sat Oct 17 2009 Thomas Spura <tomspur@fedoraproject.org> - 1.1.6-2
- disable static library
- patch for double named header files
- extra doc package

* Fri Dec 12 2008 Conrad Meyer <konrad@tylerc.org> - 1.1.6-1
- Initial package.
